from setuptools import setup, find_packages

setup(
    name='renus',
    version='1.0.8',
    description='Renus Core Framework',
    url='https://github.com/smkoBa/renus',
    author='Smko Bayazidi',
    author_email='ba.smko@gmail.com',
    license='BSD',
    packages=find_packages(),
)